==> ng2d3-1.7.1.tgz: package/src/number-card/card-series.component.ts <==
import {
  Component,
  Input,
  Output,
  EventEmitter,
  OnChanges,
  ChangeDetectionStrategy,
  NgZone
} from '@angular/core';

export interface CardModel {
  x;
  y;
  width: number;
  height: number;
  color: string;
  label: string;
  data;
  tooltipText: string;
}

@Component({
  selector: 'g[cardSeries]',
  template: `
    <svg:g card *ngFor="let c of cards; trackBy:trackBy"
      [x]="c.x"
      [y]="c.y"
      [width]="c.width"
      [height]="c.height"
      [color]="c.color"
      [data]="c.data"
      (clickHandler)="click($event)"
    />
  `,
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class CardSeries implements OnChanges {
  cards: CardModel[];

  @Input() data;
  @Input() dims;
  @Input() colors;

  @Output() clickHandler = new EventEmitter();

  constructor(private zone: NgZone) {

  }

  ngOnChanges() {
    this.update();
  }

  update() {
    this.zone.run(() => {
      this.cards = this.getCards();
    });
  }

  getCards() {
    return this.data
      .map((d, index) => {
        let label = d.data.name;
        if (label.constructor.name === 'Date') {
          label = label.toLocaleDateString();
        } else {
          label = label.toLocaleString();
        }
        d.data.name = label;

        let value = d.data.value;
        return {
          x: d.x,
          y: d.y,
          width: d.width,
          height: d.height,
          color: this.colors(label),
          label: label,
          data: d.data,
          tooltipText: `${label}: ${value}`
        };
      });
  }

  trackBy(index, card) {
    return card.label;
  }

  click(data) {
    this.clickHandler.emit(data);
  }

}

==> ng2d3-1.8.0.tgz: package/src/number-card/card-series.component.ts <==
import {
  Component,
  Input,
  Output,
  EventEmitter,
  OnChanges,
  ChangeDetectionStrategy,
  NgZone
} from '@angular/core';

export interface CardModel {
  x;
  y;
  width: number;
  height: number;
  color: string;
  label: string;
  data;
  tooltipText: string;
}

@Component({
  selector: 'g[cardSeries]',
  template: `
    <svg:g card *ngFor="let c of cards; trackBy:trackBy"
      [x]="c.x"
      [y]="c.y"
      [width]="c.width"
      [height]="c.height"
      [color]="c.color"
      [data]="c.data"
      (clickHandler)="onClick($event)"
    />
  `,
  changeDetection: ChangeDetectionStrategy.OnPush
})
export class CardSeriesComponent implements OnChanges {

  @Input() data;
  @Input() dims;
  @Input() colors;

  @Output() clickHandler = new EventEmitter();

  cards: CardModel[];

  constructor(private zone: NgZone) { }

  ngOnChanges(): void {
    this.update();
  }

  update(): void {
    this.zone.run(() => {
      this.cards = this.getCards();
    });
  }

  getCards(): any[] {
    return this.data
      .map((d, index) => {
        let label = d.data.name;
        if (label.constructor.name === 'Date') {
          label = label.toLocaleDateString();
        } else {
          label = label.toLocaleString();
        }
        d.data.name = label;

        let value = d.data.value;
        return {
          x: d.x,
          y: d.y,
          width: d.width,
          height: d.height,
          color: this.colors(label),
          label: label,
          data: d.data,
          tooltipText: `${label}: ${value}`
        };
      });
  }

  trackBy(index, card): string {
    return card.label;
  }

  onClick(data): void {
    this.clickHandler.emit(data);
  }

}
